SessionCrypto class

Constructors

SessionCrypto({String? pk})

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateKey ↔ PrivateKey
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String
latefinal

Methods

decrypt(String message, String stringSenderPubKey) → String
encrypt(String message, String stringReceiverPubKey) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited