WalletNotSupportFeatureError class

Inheritance

Constructors

WalletNotSupportFeatureError(String? message)

Properties

hashCode → int
The hash code for this object.
no setterinherited
info ↔ String?
finalgetter/setter pairinherited-setteroverride-getter
message ↔ String?
getter/setter pairinherited
prefix → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited