DefaultStorage class

Implemented types

Constructors

DefaultStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePrefix → String
final

Methods

getItem({required String key, String? defaultValue}) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem({required String key}) → Future<void>
override
setItem({required String key, required String value}) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited