IStorage class abstract

Implementers

Constructors

IStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getItem({required String key, String? defaultValue}) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem({required String key}) → Future<void>
setItem({required String key, required String value}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keyConnection → const String
keyLastEventId → const String