TonConnectManager class

Constructors

TonConnectManager(String manifestUrl, {IStorage? customStorage, String? walletsListSource, int? walletsListCacheTtl, Level? logLevel = Level.nothing})

Properties

connectedWalletInfo WalletInfo?
no setter
connector TonConnect
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
messagesStream Stream<TonPaymentStatus>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedWallet WalletApp?
getter/setter pair
status TonPaymentStatus
getter/setter pair
getter/setter pair

Methods

broadcastMessage(TonPaymentStatus updatedStatus) → void
disconnect() Future<void>
loadWallets() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTrx({required String address, required int amount, String? comment, int? validUntill}) → void
Send transaction with specified data.
sendTrxRaw({required Map<String, dynamic> transaction}) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

logLevel ↔ Level?
getter/setter pair
wallets List<WalletApp>
getter/setter pair